# coding: utf-8

"""
    Pulp 3 API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_ansible
from pulpcore.client.pulp_ansible.models.inline_response2007 import InlineResponse2007  # noqa: E501
from pulpcore.client.pulp_ansible.rest import ApiException

class TestInlineResponse2007(unittest.TestCase):
    """InlineResponse2007 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test InlineResponse2007
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_ansible.models.inline_response2007.InlineResponse2007()  # noqa: E501
        if include_optional :
            return InlineResponse2007(
                count = 56, 
                next = '0', 
                previous = '0', 
                results = [
                    pulpcore.client.pulp_ansible.models.ansible/ansible_repository_read.ansible.AnsibleRepositoryRead(
                        pulp_href = '0', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        versions_href = '0', 
                        latest_version_href = '0', 
                        name = '0', 
                        description = '0', )
                    ]
            )
        else :
            return InlineResponse2007(
                count = 56,
                results = [
                    pulpcore.client.pulp_ansible.models.ansible/ansible_repository_read.ansible.AnsibleRepositoryRead(
                        pulp_href = '0', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        versions_href = '0', 
                        latest_version_href = '0', 
                        name = '0', 
                        description = '0', )
                    ],
        )

    def testInlineResponse2007(self):
        """Test InlineResponse2007"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_ansible
from pulpcore.client.pulp_ansible.models.ansible_ansible_remote import AnsibleAnsibleRemote  # noqa: E501
from pulpcore.client.pulp_ansible.rest import ApiException

class TestAnsibleAnsibleRemote(unittest.TestCase):
    """AnsibleAnsibleRemote unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AnsibleAnsibleRemote
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_ansible.models.ansible_ansible_remote.AnsibleAnsibleRemote()  # noqa: E501
        if include_optional :
            return AnsibleAnsibleRemote(
                pulp_href = '0', 
                pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                name = '0', 
                url = '0', 
                ca_cert = '0', 
                client_cert = '0', 
                client_key = '0', 
                tls_validation = True, 
                proxy_url = '0', 
                username = '0', 
                password = '0', 
                pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                download_concurrency = 1, 
                policy = 'immediate'
            )
        else :
            return AnsibleAnsibleRemote(
                name = '0',
                url = '0',
        )

    def testAnsibleAnsibleRemote(self):
        """Test AnsibleAnsibleRemote"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Pulp 3 API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from pulpcore.client.pulp_ansible.models.ansible_ansible_distribution import AnsibleAnsibleDistribution
from pulpcore.client.pulp_ansible.models.ansible_ansible_distribution_read import AnsibleAnsibleDistributionRead
from pulpcore.client.pulp_ansible.models.ansible_ansible_remote import AnsibleAnsibleRemote
from pulpcore.client.pulp_ansible.models.ansible_ansible_remote_read import AnsibleAnsibleRemoteRead
from pulpcore.client.pulp_ansible.models.ansible_ansible_repository import AnsibleAnsibleRepository
from pulpcore.client.pulp_ansible.models.ansible_ansible_repository_read import AnsibleAnsibleRepositoryRead
from pulpcore.client.pulp_ansible.models.ansible_collection_read import AnsibleCollectionRead
from pulpcore.client.pulp_ansible.models.ansible_collection_remote import AnsibleCollectionRemote
from pulpcore.client.pulp_ansible.models.ansible_collection_remote_read import AnsibleCollectionRemoteRead
from pulpcore.client.pulp_ansible.models.ansible_collection_version import AnsibleCollectionVersion
from pulpcore.client.pulp_ansible.models.ansible_collection_version_read import AnsibleCollectionVersionRead
from pulpcore.client.pulp_ansible.models.ansible_role import AnsibleRole
from pulpcore.client.pulp_ansible.models.ansible_role_read import AnsibleRoleRead
from pulpcore.client.pulp_ansible.models.ansible_tag import AnsibleTag
from pulpcore.client.pulp_ansible.models.async_operation_response import AsyncOperationResponse
from pulpcore.client.pulp_ansible.models.collection import Collection
from pulpcore.client.pulp_ansible.models.collection_import_detail_read import CollectionImportDetailRead
from pulpcore.client.pulp_ansible.models.collection_metadata import CollectionMetadata
from pulpcore.client.pulp_ansible.models.collection_namespace import CollectionNamespace
from pulpcore.client.pulp_ansible.models.collection_read import CollectionRead
from pulpcore.client.pulp_ansible.models.collection_ref import CollectionRef
from pulpcore.client.pulp_ansible.models.collection_version import CollectionVersion
from pulpcore.client.pulp_ansible.models.collection_version_read import CollectionVersionRead
from pulpcore.client.pulp_ansible.models.content_summary import ContentSummary
from pulpcore.client.pulp_ansible.models.galaxy_collection import GalaxyCollection
from pulpcore.client.pulp_ansible.models.galaxy_collection_read import GalaxyCollectionRead
from pulpcore.client.pulp_ansible.models.galaxy_collection_version_read import GalaxyCollectionVersionRead
from pulpcore.client.pulp_ansible.models.galaxy_role_read import GalaxyRoleRead
from pulpcore.client.pulp_ansible.models.galaxy_role_version_read import GalaxyRoleVersionRead
from pulpcore.client.pulp_ansible.models.inline_response200 import InlineResponse200
from pulpcore.client.pulp_ansible.models.inline_response2001 import InlineResponse2001
from pulpcore.client.pulp_ansible.models.inline_response20010 import InlineResponse20010
from pulpcore.client.pulp_ansible.models.inline_response20011 import InlineResponse20011
from pulpcore.client.pulp_ansible.models.inline_response20012 import InlineResponse20012
from pulpcore.client.pulp_ansible.models.inline_response20013 import InlineResponse20013
from pulpcore.client.pulp_ansible.models.inline_response2002 import InlineResponse2002
from pulpcore.client.pulp_ansible.models.inline_response2003 import InlineResponse2003
from pulpcore.client.pulp_ansible.models.inline_response2004 import InlineResponse2004
from pulpcore.client.pulp_ansible.models.inline_response2005 import InlineResponse2005
from pulpcore.client.pulp_ansible.models.inline_response2006 import InlineResponse2006
from pulpcore.client.pulp_ansible.models.inline_response2007 import InlineResponse2007
from pulpcore.client.pulp_ansible.models.inline_response2008 import InlineResponse2008
from pulpcore.client.pulp_ansible.models.inline_response2009 import InlineResponse2009
from pulpcore.client.pulp_ansible.models.repository_add_remove_content import RepositoryAddRemoveContent
from pulpcore.client.pulp_ansible.models.repository_sync_url import RepositorySyncURL
from pulpcore.client.pulp_ansible.models.repository_version import RepositoryVersion
from pulpcore.client.pulp_ansible.models.repository_version_read import RepositoryVersionRead
from pulpcore.client.pulp_ansible.models.tag_read import TagRead



# coding: utf-8

"""
    Pulp 3 API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_ansible.configuration import Configuration


class AnsibleCollectionVersion(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'artifact': 'str',
        'pulp_href': 'str',
        'pulp_created': 'datetime',
        'md5': 'str',
        'sha1': 'str',
        'sha224': 'str',
        'sha256': 'str',
        'sha384': 'str',
        'sha512': 'str',
        'id': 'str',
        'authors': 'list[str]',
        'contents': 'list[dict(str, str)]',
        'dependencies': 'dict(str, str)',
        'description': 'str',
        'docs_blob': 'dict(str, str)',
        'documentation': 'str',
        'homepage': 'str',
        'issues': 'str',
        'certification': 'str',
        'license': 'list[str]',
        'name': 'str',
        'namespace': 'str',
        'repository': 'str',
        'tags': 'list[AnsibleTag]',
        'version': 'str',
        'deprecated': 'bool'
    }

    attribute_map = {
        'artifact': 'artifact',
        'pulp_href': 'pulp_href',
        'pulp_created': 'pulp_created',
        'md5': 'md5',
        'sha1': 'sha1',
        'sha224': 'sha224',
        'sha256': 'sha256',
        'sha384': 'sha384',
        'sha512': 'sha512',
        'id': 'id',
        'authors': 'authors',
        'contents': 'contents',
        'dependencies': 'dependencies',
        'description': 'description',
        'docs_blob': 'docs_blob',
        'documentation': 'documentation',
        'homepage': 'homepage',
        'issues': 'issues',
        'certification': 'certification',
        'license': 'license',
        'name': 'name',
        'namespace': 'namespace',
        'repository': 'repository',
        'tags': 'tags',
        'version': 'version',
        'deprecated': 'deprecated'
    }

    def __init__(self, artifact=None, pulp_href=None, pulp_created=None, md5=None, sha1=None, sha224=None, sha256=None, sha384=None, sha512=None, id=None, authors=None, contents=None, dependencies=None, description=None, docs_blob=None, documentation=None, homepage=None, issues=None, certification=None, license=None, name=None, namespace=None, repository=None, tags=None, version=None, deprecated=None, local_vars_configuration=None):  # noqa: E501
        """AnsibleCollectionVersion - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._artifact = None
        self._pulp_href = None
        self._pulp_created = None
        self._md5 = None
        self._sha1 = None
        self._sha224 = None
        self._sha256 = None
        self._sha384 = None
        self._sha512 = None
        self._id = None
        self._authors = None
        self._contents = None
        self._dependencies = None
        self._description = None
        self._docs_blob = None
        self._documentation = None
        self._homepage = None
        self._issues = None
        self._certification = None
        self._license = None
        self._name = None
        self._namespace = None
        self._repository = None
        self._tags = None
        self._version = None
        self._deprecated = None
        self.discriminator = None

        self.artifact = artifact
        if pulp_href is not None:
            self.pulp_href = pulp_href
        if pulp_created is not None:
            self.pulp_created = pulp_created
        if md5 is not None:
            self.md5 = md5
        if sha1 is not None:
            self.sha1 = sha1
        if sha224 is not None:
            self.sha224 = sha224
        if sha256 is not None:
            self.sha256 = sha256
        if sha384 is not None:
            self.sha384 = sha384
        if sha512 is not None:
            self.sha512 = sha512
        self.id = id
        self.authors = authors
        self.contents = contents
        self.dependencies = dependencies
        self.description = description
        self.docs_blob = docs_blob
        self.documentation = documentation
        self.homepage = homepage
        self.issues = issues
        self.certification = certification
        self.license = license
        self.name = name
        self.namespace = namespace
        self.repository = repository
        if tags is not None:
            self.tags = tags
        self.version = version
        if deprecated is not None:
            self.deprecated = deprecated

    @property
    def artifact(self):
        """Gets the artifact of this AnsibleCollectionVersion.  # noqa: E501

        Artifact file representing the physical content  # noqa: E501

        :return: The artifact of this AnsibleCollectionVersion.  # noqa: E501
        :rtype: str
        """
        return self._artifact

    @artifact.setter
    def artifact(self, artifact):
        """Sets the artifact of this AnsibleCollectionVersion.

        Artifact file representing the physical content  # noqa: E501

        :param artifact: The artifact of this AnsibleCollectionVersion.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and artifact is None:  # noqa: E501
            raise ValueError("Invalid value for `artifact`, must not be `None`")  # noqa: E501

        self._artifact = artifact

    @property
    def pulp_href(self):
        """Gets the pulp_href of this AnsibleCollectionVersion.  # noqa: E501


        :return: The pulp_href of this AnsibleCollectionVersion.  # noqa: E501
        :rtype: str
        """
        return self._pulp_href

    @pulp_href.setter
    def pulp_href(self, pulp_href):
        """Sets the pulp_href of this AnsibleCollectionVersion.


        :param pulp_href: The pulp_href of this AnsibleCollectionVersion.  # noqa: E501
        :type: str
        """

        self._pulp_href = pulp_href

    @property
    def pulp_created(self):
        """Gets the pulp_created of this AnsibleCollectionVersion.  # noqa: E501

        Timestamp of creation.  # noqa: E501

        :return: The pulp_created of this AnsibleCollectionVersion.  # noqa: E501
        :rtype: datetime
        """
        return self._pulp_created

    @pulp_created.setter
    def pulp_created(self, pulp_created):
        """Sets the pulp_created of this AnsibleCollectionVersion.

        Timestamp of creation.  # noqa: E501

        :param pulp_created: The pulp_created of this AnsibleCollectionVersion.  # noqa: E501
        :type: datetime
        """

        self._pulp_created = pulp_created

    @property
    def md5(self):
        """Gets the md5 of this AnsibleCollectionVersion.  # noqa: E501

        The MD5 checksum if available.  # noqa: E501

        :return: The md5 of this AnsibleCollectionVersion.  # noqa: E501
        :rtype: str
        """
        return self._md5

    @md5.setter
    def md5(self, md5):
        """Sets the md5 of this AnsibleCollectionVersion.

        The MD5 checksum if available.  # noqa: E501

        :param md5: The md5 of this AnsibleCollectionVersion.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                md5 is not None and len(md5) < 1):
            raise ValueError("Invalid value for `md5`, length must be greater than or equal to `1`")  # noqa: E501

        self._md5 = md5

    @property
    def sha1(self):
        """Gets the sha1 of this AnsibleCollectionVersion.  # noqa: E501

        The SHA-1 checksum if available.  # noqa: E501

        :return: The sha1 of this AnsibleCollectionVersion.  # noqa: E501
        :rtype: str
        """
        return self._sha1

    @sha1.setter
    def sha1(self, sha1):
        """Sets the sha1 of this AnsibleCollectionVersion.

        The SHA-1 checksum if available.  # noqa: E501

        :param sha1: The sha1 of this AnsibleCollectionVersion.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                sha1 is not None and len(sha1) < 1):
            raise ValueError("Invalid value for `sha1`, length must be greater than or equal to `1`")  # noqa: E501

        self._sha1 = sha1

    @property
    def sha224(self):
        """Gets the sha224 of this AnsibleCollectionVersion.  # noqa: E501

        The SHA-224 checksum if available.  # noqa: E501

        :return: The sha224 of this AnsibleCollectionVersion.  # noqa: E501
        :rtype: str
        """
        return self._sha224

    @sha224.setter
    def sha224(self, sha224):
        """Sets the sha224 of this AnsibleCollectionVersion.

        The SHA-224 checksum if available.  # noqa: E501

        :param sha224: The sha224 of this AnsibleCollectionVersion.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                sha224 is not None and len(sha224) < 1):
            raise ValueError("Invalid value for `sha224`, length must be greater than or equal to `1`")  # noqa: E501

        self._sha224 = sha224

    @property
    def sha256(self):
        """Gets the sha256 of this AnsibleCollectionVersion.  # noqa: E501

        The SHA-256 checksum if available.  # noqa: E501

        :return: The sha256 of this AnsibleCollectionVersion.  # noqa: E501
        :rtype: str
        """
        return self._sha256

    @sha256.setter
    def sha256(self, sha256):
        """Sets the sha256 of this AnsibleCollectionVersion.

        The SHA-256 checksum if available.  # noqa: E501

        :param sha256: The sha256 of this AnsibleCollectionVersion.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                sha256 is not None and len(sha256) < 1):
            raise ValueError("Invalid value for `sha256`, length must be greater than or equal to `1`")  # noqa: E501

        self._sha256 = sha256

    @property
    def sha384(self):
        """Gets the sha384 of this AnsibleCollectionVersion.  # noqa: E501

        The SHA-384 checksum if available.  # noqa: E501

        :return: The sha384 of this AnsibleCollectionVersion.  # noqa: E501
        :rtype: str
        """
        return self._sha384

    @sha384.setter
    def sha384(self, sha384):
        """Sets the sha384 of this AnsibleCollectionVersion.

        The SHA-384 checksum if available.  # noqa: E501

        :param sha384: The sha384 of this AnsibleCollectionVersion.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                sha384 is not None and len(sha384) < 1):
            raise ValueError("Invalid value for `sha384`, length must be greater than or equal to `1`")  # noqa: E501

        self._sha384 = sha384

    @property
    def sha512(self):
        """Gets the sha512 of this AnsibleCollectionVersion.  # noqa: E501

        The SHA-512 checksum if available.  # noqa: E501

        :return: The sha512 of this AnsibleCollectionVersion.  # noqa: E501
        :rtype: str
        """
        return self._sha512

    @sha512.setter
    def sha512(self, sha512):
        """Sets the sha512 of this AnsibleCollectionVersion.

        The SHA-512 checksum if available.  # noqa: E501

        :param sha512: The sha512 of this AnsibleCollectionVersion.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                sha512 is not None and len(sha512) < 1):
            raise ValueError("Invalid value for `sha512`, length must be greater than or equal to `1`")  # noqa: E501

        self._sha512 = sha512

    @property
    def id(self):
        """Gets the id of this AnsibleCollectionVersion.  # noqa: E501

        A collection identifier.  # noqa: E501

        :return: The id of this AnsibleCollectionVersion.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AnsibleCollectionVersion.

        A collection identifier.  # noqa: E501

        :param id: The id of this AnsibleCollectionVersion.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def authors(self):
        """Gets the authors of this AnsibleCollectionVersion.  # noqa: E501

        A list of the CollectionVersion content's authors.  # noqa: E501

        :return: The authors of this AnsibleCollectionVersion.  # noqa: E501
        :rtype: list[str]
        """
        return self._authors

    @authors.setter
    def authors(self, authors):
        """Sets the authors of this AnsibleCollectionVersion.

        A list of the CollectionVersion content's authors.  # noqa: E501

        :param authors: The authors of this AnsibleCollectionVersion.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and authors is None:  # noqa: E501
            raise ValueError("Invalid value for `authors`, must not be `None`")  # noqa: E501

        self._authors = authors

    @property
    def contents(self):
        """Gets the contents of this AnsibleCollectionVersion.  # noqa: E501

        A JSON field with data about the contents.  # noqa: E501

        :return: The contents of this AnsibleCollectionVersion.  # noqa: E501
        :rtype: list[dict(str, str)]
        """
        return self._contents

    @contents.setter
    def contents(self, contents):
        """Sets the contents of this AnsibleCollectionVersion.

        A JSON field with data about the contents.  # noqa: E501

        :param contents: The contents of this AnsibleCollectionVersion.  # noqa: E501
        :type: list[dict(str, str)]
        """
        if self.local_vars_configuration.client_side_validation and contents is None:  # noqa: E501
            raise ValueError("Invalid value for `contents`, must not be `None`")  # noqa: E501

        self._contents = contents

    @property
    def dependencies(self):
        """Gets the dependencies of this AnsibleCollectionVersion.  # noqa: E501

        A dict declaring Collections that this collection requires to be installed for it to be usable.  # noqa: E501

        :return: The dependencies of this AnsibleCollectionVersion.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._dependencies

    @dependencies.setter
    def dependencies(self, dependencies):
        """Sets the dependencies of this AnsibleCollectionVersion.

        A dict declaring Collections that this collection requires to be installed for it to be usable.  # noqa: E501

        :param dependencies: The dependencies of this AnsibleCollectionVersion.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and dependencies is None:  # noqa: E501
            raise ValueError("Invalid value for `dependencies`, must not be `None`")  # noqa: E501

        self._dependencies = dependencies

    @property
    def description(self):
        """Gets the description of this AnsibleCollectionVersion.  # noqa: E501

        A short summary description of the collection.  # noqa: E501

        :return: The description of this AnsibleCollectionVersion.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AnsibleCollectionVersion.

        A short summary description of the collection.  # noqa: E501

        :param description: The description of this AnsibleCollectionVersion.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and description is None:  # noqa: E501
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def docs_blob(self):
        """Gets the docs_blob of this AnsibleCollectionVersion.  # noqa: E501

        A JSON field holding the various documentation blobs in the collection.  # noqa: E501

        :return: The docs_blob of this AnsibleCollectionVersion.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._docs_blob

    @docs_blob.setter
    def docs_blob(self, docs_blob):
        """Sets the docs_blob of this AnsibleCollectionVersion.

        A JSON field holding the various documentation blobs in the collection.  # noqa: E501

        :param docs_blob: The docs_blob of this AnsibleCollectionVersion.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and docs_blob is None:  # noqa: E501
            raise ValueError("Invalid value for `docs_blob`, must not be `None`")  # noqa: E501

        self._docs_blob = docs_blob

    @property
    def documentation(self):
        """Gets the documentation of this AnsibleCollectionVersion.  # noqa: E501

        The URL to any online docs.  # noqa: E501

        :return: The documentation of this AnsibleCollectionVersion.  # noqa: E501
        :rtype: str
        """
        return self._documentation

    @documentation.setter
    def documentation(self, documentation):
        """Sets the documentation of this AnsibleCollectionVersion.

        The URL to any online docs.  # noqa: E501

        :param documentation: The documentation of this AnsibleCollectionVersion.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and documentation is None:  # noqa: E501
            raise ValueError("Invalid value for `documentation`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                documentation is not None and len(documentation) > 2000):
            raise ValueError("Invalid value for `documentation`, length must be less than or equal to `2000`")  # noqa: E501

        self._documentation = documentation

    @property
    def homepage(self):
        """Gets the homepage of this AnsibleCollectionVersion.  # noqa: E501

        The URL to the homepage of the collection/project.  # noqa: E501

        :return: The homepage of this AnsibleCollectionVersion.  # noqa: E501
        :rtype: str
        """
        return self._homepage

    @homepage.setter
    def homepage(self, homepage):
        """Sets the homepage of this AnsibleCollectionVersion.

        The URL to the homepage of the collection/project.  # noqa: E501

        :param homepage: The homepage of this AnsibleCollectionVersion.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and homepage is None:  # noqa: E501
            raise ValueError("Invalid value for `homepage`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                homepage is not None and len(homepage) > 2000):
            raise ValueError("Invalid value for `homepage`, length must be less than or equal to `2000`")  # noqa: E501

        self._homepage = homepage

    @property
    def issues(self):
        """Gets the issues of this AnsibleCollectionVersion.  # noqa: E501

        The URL to the collection issue tracker.  # noqa: E501

        :return: The issues of this AnsibleCollectionVersion.  # noqa: E501
        :rtype: str
        """
        return self._issues

    @issues.setter
    def issues(self, issues):
        """Sets the issues of this AnsibleCollectionVersion.

        The URL to the collection issue tracker.  # noqa: E501

        :param issues: The issues of this AnsibleCollectionVersion.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and issues is None:  # noqa: E501
            raise ValueError("Invalid value for `issues`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                issues is not None and len(issues) > 2000):
            raise ValueError("Invalid value for `issues`, length must be less than or equal to `2000`")  # noqa: E501

        self._issues = issues

    @property
    def certification(self):
        """Gets the certification of this AnsibleCollectionVersion.  # noqa: E501

        Indicates that the version is certified  # noqa: E501

        :return: The certification of this AnsibleCollectionVersion.  # noqa: E501
        :rtype: str
        """
        return self._certification

    @certification.setter
    def certification(self, certification):
        """Sets the certification of this AnsibleCollectionVersion.

        Indicates that the version is certified  # noqa: E501

        :param certification: The certification of this AnsibleCollectionVersion.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and certification is None:  # noqa: E501
            raise ValueError("Invalid value for `certification`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                certification is not None and len(certification) < 1):
            raise ValueError("Invalid value for `certification`, length must be greater than or equal to `1`")  # noqa: E501

        self._certification = certification

    @property
    def license(self):
        """Gets the license of this AnsibleCollectionVersion.  # noqa: E501

        A list of licenses for content inside of a collection.  # noqa: E501

        :return: The license of this AnsibleCollectionVersion.  # noqa: E501
        :rtype: list[str]
        """
        return self._license

    @license.setter
    def license(self, license):
        """Sets the license of this AnsibleCollectionVersion.

        A list of licenses for content inside of a collection.  # noqa: E501

        :param license: The license of this AnsibleCollectionVersion.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and license is None:  # noqa: E501
            raise ValueError("Invalid value for `license`, must not be `None`")  # noqa: E501

        self._license = license

    @property
    def name(self):
        """Gets the name of this AnsibleCollectionVersion.  # noqa: E501

        The name of the collection.  # noqa: E501

        :return: The name of this AnsibleCollectionVersion.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AnsibleCollectionVersion.

        The name of the collection.  # noqa: E501

        :param name: The name of this AnsibleCollectionVersion.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 32):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `32`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def namespace(self):
        """Gets the namespace of this AnsibleCollectionVersion.  # noqa: E501

        The namespace of the collection.  # noqa: E501

        :return: The namespace of this AnsibleCollectionVersion.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this AnsibleCollectionVersion.

        The namespace of the collection.  # noqa: E501

        :param namespace: The namespace of this AnsibleCollectionVersion.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and namespace is None:  # noqa: E501
            raise ValueError("Invalid value for `namespace`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                namespace is not None and len(namespace) > 32):
            raise ValueError("Invalid value for `namespace`, length must be less than or equal to `32`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                namespace is not None and len(namespace) < 1):
            raise ValueError("Invalid value for `namespace`, length must be greater than or equal to `1`")  # noqa: E501

        self._namespace = namespace

    @property
    def repository(self):
        """Gets the repository of this AnsibleCollectionVersion.  # noqa: E501

        The URL of the originating SCM repository.  # noqa: E501

        :return: The repository of this AnsibleCollectionVersion.  # noqa: E501
        :rtype: str
        """
        return self._repository

    @repository.setter
    def repository(self, repository):
        """Sets the repository of this AnsibleCollectionVersion.

        The URL of the originating SCM repository.  # noqa: E501

        :param repository: The repository of this AnsibleCollectionVersion.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and repository is None:  # noqa: E501
            raise ValueError("Invalid value for `repository`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                repository is not None and len(repository) > 2000):
            raise ValueError("Invalid value for `repository`, length must be less than or equal to `2000`")  # noqa: E501

        self._repository = repository

    @property
    def tags(self):
        """Gets the tags of this AnsibleCollectionVersion.  # noqa: E501


        :return: The tags of this AnsibleCollectionVersion.  # noqa: E501
        :rtype: list[AnsibleTag]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this AnsibleCollectionVersion.


        :param tags: The tags of this AnsibleCollectionVersion.  # noqa: E501
        :type: list[AnsibleTag]
        """

        self._tags = tags

    @property
    def version(self):
        """Gets the version of this AnsibleCollectionVersion.  # noqa: E501

        The version of the collection.  # noqa: E501

        :return: The version of this AnsibleCollectionVersion.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this AnsibleCollectionVersion.

        The version of the collection.  # noqa: E501

        :param version: The version of this AnsibleCollectionVersion.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and version is None:  # noqa: E501
            raise ValueError("Invalid value for `version`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                version is not None and len(version) > 32):
            raise ValueError("Invalid value for `version`, length must be less than or equal to `32`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                version is not None and len(version) < 1):
            raise ValueError("Invalid value for `version`, length must be greater than or equal to `1`")  # noqa: E501

        self._version = version

    @property
    def deprecated(self):
        """Gets the deprecated of this AnsibleCollectionVersion.  # noqa: E501

        Whether or not the collection has been deprecated.  # noqa: E501

        :return: The deprecated of this AnsibleCollectionVersion.  # noqa: E501
        :rtype: bool
        """
        return self._deprecated

    @deprecated.setter
    def deprecated(self, deprecated):
        """Sets the deprecated of this AnsibleCollectionVersion.

        Whether or not the collection has been deprecated.  # noqa: E501

        :param deprecated: The deprecated of this AnsibleCollectionVersion.  # noqa: E501
        :type: bool
        """

        self._deprecated = deprecated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnsibleCollectionVersion):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AnsibleCollectionVersion):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_ansible
from pulpcore.client.pulp_ansible.models.collection_metadata import CollectionMetadata  # noqa: E501
from pulpcore.client.pulp_ansible.rest import ApiException

class TestCollectionMetadata(unittest.TestCase):
    """CollectionMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CollectionMetadata
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_ansible.models.collection_metadata.CollectionMetadata()  # noqa: E501
        if include_optional :
            return CollectionMetadata(
                authors = [
                    '0'
                    ], 
                contents = pulpcore.client.pulp_ansible.models.contents.Contents(), 
                dependencies = pulpcore.client.pulp_ansible.models.dependencies.Dependencies(), 
                description = '0', 
                documentation = '0', 
                homepage = '0', 
                issues = '0', 
                license = [
                    '0'
                    ], 
                repository = '0', 
                tags = [
                    '0'
                    ]
            )
        else :
            return CollectionMetadata(
                tags = [
                    '0'
                    ],
        )

    def testCollectionMetadata(self):
        """Test CollectionMetadata"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_ansible.configuration import Configuration


class CollectionRead(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'href': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'namespace': 'str',
        'name': 'str',
        'deprecated': 'bool',
        'versions_url': 'str',
        'highest_version': 'str'
    }

    attribute_map = {
        'href': 'href',
        'created_at': 'created_at',
        'updated_at': 'updated_at',
        'namespace': 'namespace',
        'name': 'name',
        'deprecated': 'deprecated',
        'versions_url': 'versions_url',
        'highest_version': 'highest_version'
    }

    def __init__(self, href=None, created_at=None, updated_at=None, namespace=None, name=None, deprecated=None, versions_url=None, highest_version=None, local_vars_configuration=None):  # noqa: E501
        """CollectionRead - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._href = None
        self._created_at = None
        self._updated_at = None
        self._namespace = None
        self._name = None
        self._deprecated = None
        self._versions_url = None
        self._highest_version = None
        self.discriminator = None

        if href is not None:
            self.href = href
        self.created_at = created_at
        self.updated_at = updated_at
        if namespace is not None:
            self.namespace = namespace
        if name is not None:
            self.name = name
        self.deprecated = deprecated
        if versions_url is not None:
            self.versions_url = versions_url
        if highest_version is not None:
            self.highest_version = highest_version

    @property
    def href(self):
        """Gets the href of this CollectionRead.  # noqa: E501


        :return: The href of this CollectionRead.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this CollectionRead.


        :param href: The href of this CollectionRead.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def created_at(self):
        """Gets the created_at of this CollectionRead.  # noqa: E501


        :return: The created_at of this CollectionRead.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this CollectionRead.


        :param created_at: The created_at of this CollectionRead.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this CollectionRead.  # noqa: E501


        :return: The updated_at of this CollectionRead.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this CollectionRead.


        :param updated_at: The updated_at of this CollectionRead.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    @property
    def namespace(self):
        """Gets the namespace of this CollectionRead.  # noqa: E501


        :return: The namespace of this CollectionRead.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this CollectionRead.


        :param namespace: The namespace of this CollectionRead.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                namespace is not None and len(namespace) < 1):
            raise ValueError("Invalid value for `namespace`, length must be greater than or equal to `1`")  # noqa: E501

        self._namespace = namespace

    @property
    def name(self):
        """Gets the name of this CollectionRead.  # noqa: E501


        :return: The name of this CollectionRead.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CollectionRead.


        :param name: The name of this CollectionRead.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def deprecated(self):
        """Gets the deprecated of this CollectionRead.  # noqa: E501


        :return: The deprecated of this CollectionRead.  # noqa: E501
        :rtype: bool
        """
        return self._deprecated

    @deprecated.setter
    def deprecated(self, deprecated):
        """Sets the deprecated of this CollectionRead.


        :param deprecated: The deprecated of this CollectionRead.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and deprecated is None:  # noqa: E501
            raise ValueError("Invalid value for `deprecated`, must not be `None`")  # noqa: E501

        self._deprecated = deprecated

    @property
    def versions_url(self):
        """Gets the versions_url of this CollectionRead.  # noqa: E501


        :return: The versions_url of this CollectionRead.  # noqa: E501
        :rtype: str
        """
        return self._versions_url

    @versions_url.setter
    def versions_url(self, versions_url):
        """Sets the versions_url of this CollectionRead.


        :param versions_url: The versions_url of this CollectionRead.  # noqa: E501
        :type: str
        """

        self._versions_url = versions_url

    @property
    def highest_version(self):
        """Gets the highest_version of this CollectionRead.  # noqa: E501


        :return: The highest_version of this CollectionRead.  # noqa: E501
        :rtype: str
        """
        return self._highest_version

    @highest_version.setter
    def highest_version(self, highest_version):
        """Sets the highest_version of this CollectionRead.


        :param highest_version: The highest_version of this CollectionRead.  # noqa: E501
        :type: str
        """

        self._highest_version = highest_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CollectionRead):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CollectionRead):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_ansible
from pulpcore.client.pulp_ansible.models.galaxy_collection_version_read import GalaxyCollectionVersionRead  # noqa: E501
from pulpcore.client.pulp_ansible.rest import ApiException

class TestGalaxyCollectionVersionRead(unittest.TestCase):
    """GalaxyCollectionVersionRead unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GalaxyCollectionVersionRead
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_ansible.models.galaxy_collection_version_read.GalaxyCollectionVersionRead()  # noqa: E501
        if include_optional :
            return GalaxyCollectionVersionRead(
                version = '0', 
                href = '0', 
                namespace = '0', 
                collection = '0', 
                artifact = '0', 
                metadata = pulpcore.client.pulp_ansible.models.metadata.Metadata(
                    authors = [
                        '0'
                        ], 
                    contents = pulpcore.client.pulp_ansible.models.contents.Contents(), 
                    dependencies = pulpcore.client.pulp_ansible.models.dependencies.Dependencies(), 
                    description = '0', 
                    documentation = '0', 
                    homepage = '0', 
                    issues = '0', 
                    license = [
                        '0'
                        ], 
                    repository = '0', 
                    tags = [
                        '0'
                        ], )
            )
        else :
            return GalaxyCollectionVersionRead(
                version = '0',
                metadata = pulpcore.client.pulp_ansible.models.metadata.Metadata(
                    authors = [
                        '0'
                        ], 
                    contents = pulpcore.client.pulp_ansible.models.contents.Contents(), 
                    dependencies = pulpcore.client.pulp_ansible.models.dependencies.Dependencies(), 
                    description = '0', 
                    documentation = '0', 
                    homepage = '0', 
                    issues = '0', 
                    license = [
                        '0'
                        ], 
                    repository = '0', 
                    tags = [
                        '0'
                        ], ),
        )

    def testGalaxyCollectionVersionRead(self):
        """Test GalaxyCollectionVersionRead"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_ansible
from pulpcore.client.pulp_ansible.models.inline_response2008 import InlineResponse2008  # noqa: E501
from pulpcore.client.pulp_ansible.rest import ApiException

class TestInlineResponse2008(unittest.TestCase):
    """InlineResponse2008 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test InlineResponse2008
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_ansible.models.inline_response2008.InlineResponse2008()  # noqa: E501
        if include_optional :
            return InlineResponse2008(
                count = 56, 
                next = '0', 
                previous = '0', 
                results = [
                    pulpcore.client.pulp_ansible.models.repository_version_read.RepositoryVersionRead(
                        pulp_href = '0', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        number = 56, 
                        base_version = '0', 
                        content_summary = pulpcore.client.pulp_ansible.models.content_summary.Content summary(
                            added = {
                                'key' : {
                                    'key' : '0'
                                    }
                                }, 
                            removed = {
                                'key' : {
                                    'key' : '0'
                                    }
                                }, 
                            present = {
                                'key' : {
                                    'key' : '0'
                                    }
                                }, ), )
                    ]
            )
        else :
            return InlineResponse2008(
                count = 56,
                results = [
                    pulpcore.client.pulp_ansible.models.repository_version_read.RepositoryVersionRead(
                        pulp_href = '0', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        number = 56, 
                        base_version = '0', 
                        content_summary = pulpcore.client.pulp_ansible.models.content_summary.Content summary(
                            added = {
                                'key' : {
                                    'key' : '0'
                                    }
                                }, 
                            removed = {
                                'key' : {
                                    'key' : '0'
                                    }
                                }, 
                            present = {
                                'key' : {
                                    'key' : '0'
                                    }
                                }, ), )
                    ],
        )

    def testInlineResponse2008(self):
        """Test InlineResponse2008"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "pulp_ansible-client"
VERSION = "0.2.0b13"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Pulp 3 API",
    author="OpenAPI Generator community",
    author_email="team@openapitools.org",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "Pulp 3 API"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="GPLv2+",
    long_description="""\
    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501
    """
)



# coding: utf-8

"""
    Pulp 3 API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_ansible.configuration import Configuration


class InlineResponse2005(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'count': 'int',
        'next': 'str',
        'previous': 'str',
        'results': 'list[AnsibleAnsibleRemoteRead]'
    }

    attribute_map = {
        'count': 'count',
        'next': 'next',
        'previous': 'previous',
        'results': 'results'
    }

    def __init__(self, count=None, next=None, previous=None, results=None, local_vars_configuration=None):  # noqa: E501
        """InlineResponse2005 - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._count = None
        self._next = None
        self._previous = None
        self._results = None
        self.discriminator = None

        self.count = count
        self.next = next
        self.previous = previous
        self.results = results

    @property
    def count(self):
        """Gets the count of this InlineResponse2005.  # noqa: E501


        :return: The count of this InlineResponse2005.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this InlineResponse2005.


        :param count: The count of this InlineResponse2005.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and count is None:  # noqa: E501
            raise ValueError("Invalid value for `count`, must not be `None`")  # noqa: E501

        self._count = count

    @property
    def next(self):
        """Gets the next of this InlineResponse2005.  # noqa: E501


        :return: The next of this InlineResponse2005.  # noqa: E501
        :rtype: str
        """
        return self._next

    @next.setter
    def next(self, next):
        """Sets the next of this InlineResponse2005.


        :param next: The next of this InlineResponse2005.  # noqa: E501
        :type: str
        """

        self._next = next

    @property
    def previous(self):
        """Gets the previous of this InlineResponse2005.  # noqa: E501


        :return: The previous of this InlineResponse2005.  # noqa: E501
        :rtype: str
        """
        return self._previous

    @previous.setter
    def previous(self, previous):
        """Sets the previous of this InlineResponse2005.


        :param previous: The previous of this InlineResponse2005.  # noqa: E501
        :type: str
        """

        self._previous = previous

    @property
    def results(self):
        """Gets the results of this InlineResponse2005.  # noqa: E501


        :return: The results of this InlineResponse2005.  # noqa: E501
        :rtype: list[AnsibleAnsibleRemoteRead]
        """
        return self._results

    @results.setter
    def results(self, results):
        """Sets the results of this InlineResponse2005.


        :param results: The results of this InlineResponse2005.  # noqa: E501
        :type: list[AnsibleAnsibleRemoteRead]
        """
        if self.local_vars_configuration.client_side_validation and results is None:  # noqa: E501
            raise ValueError("Invalid value for `results`, must not be `None`")  # noqa: E501

        self._results = results

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse2005):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse2005):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_ansible.configuration import Configuration


class AnsibleCollectionRemoteRead(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pulp_href': 'str',
        'pulp_created': 'datetime',
        'name': 'str',
        'url': 'str',
        'ca_cert': 'str',
        'client_cert': 'str',
        'client_key': 'str',
        'tls_validation': 'bool',
        'proxy_url': 'str',
        'username': 'str',
        'password': 'str',
        'pulp_last_updated': 'datetime',
        'download_concurrency': 'int',
        'policy': 'str',
        'requirements_file': 'str'
    }

    attribute_map = {
        'pulp_href': 'pulp_href',
        'pulp_created': 'pulp_created',
        'name': 'name',
        'url': 'url',
        'ca_cert': 'ca_cert',
        'client_cert': 'client_cert',
        'client_key': 'client_key',
        'tls_validation': 'tls_validation',
        'proxy_url': 'proxy_url',
        'username': 'username',
        'password': 'password',
        'pulp_last_updated': 'pulp_last_updated',
        'download_concurrency': 'download_concurrency',
        'policy': 'policy',
        'requirements_file': 'requirements_file'
    }

    def __init__(self, pulp_href=None, pulp_created=None, name=None, url=None, ca_cert=None, client_cert=None, client_key=None, tls_validation=None, proxy_url=None, username=None, password=None, pulp_last_updated=None, download_concurrency=None, policy='immediate', requirements_file=None, local_vars_configuration=None):  # noqa: E501
        """AnsibleCollectionRemoteRead - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pulp_href = None
        self._pulp_created = None
        self._name = None
        self._url = None
        self._ca_cert = None
        self._client_cert = None
        self._client_key = None
        self._tls_validation = None
        self._proxy_url = None
        self._username = None
        self._password = None
        self._pulp_last_updated = None
        self._download_concurrency = None
        self._policy = None
        self._requirements_file = None
        self.discriminator = None

        if pulp_href is not None:
            self.pulp_href = pulp_href
        if pulp_created is not None:
            self.pulp_created = pulp_created
        self.name = name
        self.url = url
        self.ca_cert = ca_cert
        self.client_cert = client_cert
        self.client_key = client_key
        if tls_validation is not None:
            self.tls_validation = tls_validation
        self.proxy_url = proxy_url
        self.username = username
        self.password = password
        if pulp_last_updated is not None:
            self.pulp_last_updated = pulp_last_updated
        if download_concurrency is not None:
            self.download_concurrency = download_concurrency
        if policy is not None:
            self.policy = policy
        self.requirements_file = requirements_file

    @property
    def pulp_href(self):
        """Gets the pulp_href of this AnsibleCollectionRemoteRead.  # noqa: E501


        :return: The pulp_href of this AnsibleCollectionRemoteRead.  # noqa: E501
        :rtype: str
        """
        return self._pulp_href

    @pulp_href.setter
    def pulp_href(self, pulp_href):
        """Sets the pulp_href of this AnsibleCollectionRemoteRead.


        :param pulp_href: The pulp_href of this AnsibleCollectionRemoteRead.  # noqa: E501
        :type: str
        """

        self._pulp_href = pulp_href

    @property
    def pulp_created(self):
        """Gets the pulp_created of this AnsibleCollectionRemoteRead.  # noqa: E501

        Timestamp of creation.  # noqa: E501

        :return: The pulp_created of this AnsibleCollectionRemoteRead.  # noqa: E501
        :rtype: datetime
        """
        return self._pulp_created

    @pulp_created.setter
    def pulp_created(self, pulp_created):
        """Sets the pulp_created of this AnsibleCollectionRemoteRead.

        Timestamp of creation.  # noqa: E501

        :param pulp_created: The pulp_created of this AnsibleCollectionRemoteRead.  # noqa: E501
        :type: datetime
        """

        self._pulp_created = pulp_created

    @property
    def name(self):
        """Gets the name of this AnsibleCollectionRemoteRead.  # noqa: E501

        A unique name for this remote.  # noqa: E501

        :return: The name of this AnsibleCollectionRemoteRead.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AnsibleCollectionRemoteRead.

        A unique name for this remote.  # noqa: E501

        :param name: The name of this AnsibleCollectionRemoteRead.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def url(self):
        """Gets the url of this AnsibleCollectionRemoteRead.  # noqa: E501

        The URL of an external content source.  # noqa: E501

        :return: The url of this AnsibleCollectionRemoteRead.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this AnsibleCollectionRemoteRead.

        The URL of an external content source.  # noqa: E501

        :param url: The url of this AnsibleCollectionRemoteRead.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and url is None:  # noqa: E501
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                url is not None and len(url) < 1):
            raise ValueError("Invalid value for `url`, length must be greater than or equal to `1`")  # noqa: E501

        self._url = url

    @property
    def ca_cert(self):
        """Gets the ca_cert of this AnsibleCollectionRemoteRead.  # noqa: E501

        A string containing the PEM encoded CA certificate used to validate the server certificate presented by the remote server. All new line characters must be escaped.  # noqa: E501

        :return: The ca_cert of this AnsibleCollectionRemoteRead.  # noqa: E501
        :rtype: str
        """
        return self._ca_cert

    @ca_cert.setter
    def ca_cert(self, ca_cert):
        """Sets the ca_cert of this AnsibleCollectionRemoteRead.

        A string containing the PEM encoded CA certificate used to validate the server certificate presented by the remote server. All new line characters must be escaped.  # noqa: E501

        :param ca_cert: The ca_cert of this AnsibleCollectionRemoteRead.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                ca_cert is not None and len(ca_cert) < 1):
            raise ValueError("Invalid value for `ca_cert`, length must be greater than or equal to `1`")  # noqa: E501

        self._ca_cert = ca_cert

    @property
    def client_cert(self):
        """Gets the client_cert of this AnsibleCollectionRemoteRead.  # noqa: E501

        A string containing the PEM encoded client certificate used for authentication. All new line characters must be escaped.  # noqa: E501

        :return: The client_cert of this AnsibleCollectionRemoteRead.  # noqa: E501
        :rtype: str
        """
        return self._client_cert

    @client_cert.setter
    def client_cert(self, client_cert):
        """Sets the client_cert of this AnsibleCollectionRemoteRead.

        A string containing the PEM encoded client certificate used for authentication. All new line characters must be escaped.  # noqa: E501

        :param client_cert: The client_cert of this AnsibleCollectionRemoteRead.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                client_cert is not None and len(client_cert) < 1):
            raise ValueError("Invalid value for `client_cert`, length must be greater than or equal to `1`")  # noqa: E501

        self._client_cert = client_cert

    @property
    def client_key(self):
        """Gets the client_key of this AnsibleCollectionRemoteRead.  # noqa: E501

        A PEM encoded private key used for authentication.  # noqa: E501

        :return: The client_key of this AnsibleCollectionRemoteRead.  # noqa: E501
        :rtype: str
        """
        return self._client_key

    @client_key.setter
    def client_key(self, client_key):
        """Sets the client_key of this AnsibleCollectionRemoteRead.

        A PEM encoded private key used for authentication.  # noqa: E501

        :param client_key: The client_key of this AnsibleCollectionRemoteRead.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                client_key is not None and len(client_key) < 1):
            raise ValueError("Invalid value for `client_key`, length must be greater than or equal to `1`")  # noqa: E501

        self._client_key = client_key

    @property
    def tls_validation(self):
        """Gets the tls_validation of this AnsibleCollectionRemoteRead.  # noqa: E501

        If True, TLS peer validation must be performed.  # noqa: E501

        :return: The tls_validation of this AnsibleCollectionRemoteRead.  # noqa: E501
        :rtype: bool
        """
        return self._tls_validation

    @tls_validation.setter
    def tls_validation(self, tls_validation):
        """Sets the tls_validation of this AnsibleCollectionRemoteRead.

        If True, TLS peer validation must be performed.  # noqa: E501

        :param tls_validation: The tls_validation of this AnsibleCollectionRemoteRead.  # noqa: E501
        :type: bool
        """

        self._tls_validation = tls_validation

    @property
    def proxy_url(self):
        """Gets the proxy_url of this AnsibleCollectionRemoteRead.  # noqa: E501

        The proxy URL. Format: scheme://user:password@host:port  # noqa: E501

        :return: The proxy_url of this AnsibleCollectionRemoteRead.  # noqa: E501
        :rtype: str
        """
        return self._proxy_url

    @proxy_url.setter
    def proxy_url(self, proxy_url):
        """Sets the proxy_url of this AnsibleCollectionRemoteRead.

        The proxy URL. Format: scheme://user:password@host:port  # noqa: E501

        :param proxy_url: The proxy_url of this AnsibleCollectionRemoteRead.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                proxy_url is not None and len(proxy_url) < 1):
            raise ValueError("Invalid value for `proxy_url`, length must be greater than or equal to `1`")  # noqa: E501

        self._proxy_url = proxy_url

    @property
    def username(self):
        """Gets the username of this AnsibleCollectionRemoteRead.  # noqa: E501

        The username to be used for authentication when syncing.  # noqa: E501

        :return: The username of this AnsibleCollectionRemoteRead.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this AnsibleCollectionRemoteRead.

        The username to be used for authentication when syncing.  # noqa: E501

        :param username: The username of this AnsibleCollectionRemoteRead.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                username is not None and len(username) < 1):
            raise ValueError("Invalid value for `username`, length must be greater than or equal to `1`")  # noqa: E501

        self._username = username

    @property
    def password(self):
        """Gets the password of this AnsibleCollectionRemoteRead.  # noqa: E501

        The password to be used for authentication when syncing.  # noqa: E501

        :return: The password of this AnsibleCollectionRemoteRead.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this AnsibleCollectionRemoteRead.

        The password to be used for authentication when syncing.  # noqa: E501

        :param password: The password of this AnsibleCollectionRemoteRead.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                password is not None and len(password) < 1):
            raise ValueError("Invalid value for `password`, length must be greater than or equal to `1`")  # noqa: E501

        self._password = password

    @property
    def pulp_last_updated(self):
        """Gets the pulp_last_updated of this AnsibleCollectionRemoteRead.  # noqa: E501

        Timestamp of the most recent update of the remote.  # noqa: E501

        :return: The pulp_last_updated of this AnsibleCollectionRemoteRead.  # noqa: E501
        :rtype: datetime
        """
        return self._pulp_last_updated

    @pulp_last_updated.setter
    def pulp_last_updated(self, pulp_last_updated):
        """Sets the pulp_last_updated of this AnsibleCollectionRemoteRead.

        Timestamp of the most recent update of the remote.  # noqa: E501

        :param pulp_last_updated: The pulp_last_updated of this AnsibleCollectionRemoteRead.  # noqa: E501
        :type: datetime
        """

        self._pulp_last_updated = pulp_last_updated

    @property
    def download_concurrency(self):
        """Gets the download_concurrency of this AnsibleCollectionRemoteRead.  # noqa: E501

        Total number of simultaneous connections.  # noqa: E501

        :return: The download_concurrency of this AnsibleCollectionRemoteRead.  # noqa: E501
        :rtype: int
        """
        return self._download_concurrency

    @download_concurrency.setter
    def download_concurrency(self, download_concurrency):
        """Sets the download_concurrency of this AnsibleCollectionRemoteRead.

        Total number of simultaneous connections.  # noqa: E501

        :param download_concurrency: The download_concurrency of this AnsibleCollectionRemoteRead.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                download_concurrency is not None and download_concurrency < 1):  # noqa: E501
            raise ValueError("Invalid value for `download_concurrency`, must be a value greater than or equal to `1`")  # noqa: E501

        self._download_concurrency = download_concurrency

    @property
    def policy(self):
        """Gets the policy of this AnsibleCollectionRemoteRead.  # noqa: E501

        The policy to use when downloading content.  # noqa: E501

        :return: The policy of this AnsibleCollectionRemoteRead.  # noqa: E501
        :rtype: str
        """
        return self._policy

    @policy.setter
    def policy(self, policy):
        """Sets the policy of this AnsibleCollectionRemoteRead.

        The policy to use when downloading content.  # noqa: E501

        :param policy: The policy of this AnsibleCollectionRemoteRead.  # noqa: E501
        :type: str
        """
        allowed_values = ["immediate", "When syncing, download all metadata and content now."]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and policy not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `policy` ({0}), must be one of {1}"  # noqa: E501
                .format(policy, allowed_values)
            )

        self._policy = policy

    @property
    def requirements_file(self):
        """Gets the requirements_file of this AnsibleCollectionRemoteRead.  # noqa: E501

        The string version of Collection requirements yaml.  # noqa: E501

        :return: The requirements_file of this AnsibleCollectionRemoteRead.  # noqa: E501
        :rtype: str
        """
        return self._requirements_file

    @requirements_file.setter
    def requirements_file(self, requirements_file):
        """Sets the requirements_file of this AnsibleCollectionRemoteRead.

        The string version of Collection requirements yaml.  # noqa: E501

        :param requirements_file: The requirements_file of this AnsibleCollectionRemoteRead.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                requirements_file is not None and len(requirements_file) < 1):
            raise ValueError("Invalid value for `requirements_file`, length must be greater than or equal to `1`")  # noqa: E501

        self._requirements_file = requirements_file

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnsibleCollectionRemoteRead):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AnsibleCollectionRemoteRead):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_ansible
from pulpcore.client.pulp_ansible.models.ansible_collection_version_read import AnsibleCollectionVersionRead  # noqa: E501
from pulpcore.client.pulp_ansible.rest import ApiException

class TestAnsibleCollectionVersionRead(unittest.TestCase):
    """AnsibleCollectionVersionRead unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AnsibleCollectionVersionRead
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_ansible.models.ansible_collection_version_read.AnsibleCollectionVersionRead()  # noqa: E501
        if include_optional :
            return AnsibleCollectionVersionRead(
                artifact = '0', 
                pulp_href = '0', 
                pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                md5 = '0', 
                sha1 = '0', 
                sha224 = '0', 
                sha256 = '0', 
                sha384 = '0', 
                sha512 = '0', 
                id = '0', 
                authors = [
                    '0'
                    ], 
                contents = [
                    {
                        'key' : '0'
                        }
                    ], 
                dependencies = {
                    'key' : '0'
                    }, 
                description = '0', 
                docs_blob = {
                    'key' : '0'
                    }, 
                documentation = '0', 
                homepage = '0', 
                issues = '0', 
                certification = '0', 
                license = [
                    '0'
                    ], 
                name = '0', 
                namespace = '0', 
                repository = '0', 
                tags = [
                    pulpcore.client.pulp_ansible.models.ansible/tag.ansible.Tag(
                        name = '0', )
                    ], 
                version = '0', 
                deprecated = True
            )
        else :
            return AnsibleCollectionVersionRead(
                artifact = '0',
                id = '0',
                authors = [
                    '0'
                    ],
                contents = [
                    {
                        'key' : '0'
                        }
                    ],
                dependencies = {
                    'key' : '0'
                    },
                description = '0',
                docs_blob = {
                    'key' : '0'
                    },
                documentation = '0',
                homepage = '0',
                issues = '0',
                certification = '0',
                license = [
                    '0'
                    ],
                name = '0',
                namespace = '0',
                repository = '0',
                version = '0',
        )

    def testAnsibleCollectionVersionRead(self):
        """Test AnsibleCollectionVersionRead"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
